Module assert

Module assert 

Functions that check set relations at compile time. Each one compiles only if the relation holds, and does nothing at runtime.

Requires the assertions feature.

Functions

contains
Asserts that the set contains the specified member.
eq
Asserts that two sets are equal. (Contain the same members.)
is_empty
Asserts that the set is empty (contains no members).
subset
Asserts that the first set is a subset of the second set.
superset
Asserts that the first set is a superset of the second set.