pub trait Contains<E>: Contains0 { }Expand description
Indicates that a type contains member E in its set.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Contains<E>: Contains0 { }Indicates that a type contains member E in its set.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".