Extend

Trait Extend 

pub trait Extend<T: ?Sized> {
    type Output: ?Sized;
}
Trait for extending a type set with another type set.

See Union for a convenient type alias to compute the union of two type sets.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, E1, E2, E3, E4, E5, E6, E7, E8, E9, E10, E11, E12> Extend<(E1, E2, E3, E4, E5, E6, E7, E8, E9, E10, E11, E12)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push<Output<E7>: Push<Output<E8>: Push<Output<E9>: Push<Output<E10>: Push<Output<E11>: Push>>>>>>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6, E7, E8, E9, E10, E11> Extend<(E1, E2, E3, E4, E5, E6, E7, E8, E9, E10, E11)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push<Output<E7>: Push<Output<E8>: Push<Output<E9>: Push<Output<E10>: Push>>>>>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6, E7, E8, E9, E10> Extend<(E1, E2, E3, E4, E5, E6, E7, E8, E9, E10)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push<Output<E7>: Push<Output<E8>: Push<Output<E9>: Push>>>>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6, E7, E8, E9> Extend<(E1, E2, E3, E4, E5, E6, E7, E8, E9)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push<Output<E7>: Push<Output<E8>: Push>>>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6, E7, E8> Extend<(E1, E2, E3, E4, E5, E6, E7, E8)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push<Output<E7>: Push>>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6, E7> Extend<(E1, E2, E3, E4, E5, E6, E7)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push<Output<E6>: Push>>>>>>,

Source

impl<T, E1, E2, E3, E4, E5, E6> Extend<(E1, E2, E3, E4, E5, E6)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push<Output<E5>: Push>>>>>,

Source

impl<T, E1, E2, E3, E4, E5> Extend<(E1, E2, E3, E4, E5)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push<Output<E4>: Push>>>>,

Source

impl<T, E1, E2, E3, E4> Extend<(E1, E2, E3, E4)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push<Output<E3>: Push>>>,

Source

impl<T, E1, E2, E3> Extend<(E1, E2, E3)> for T
where T: Push<Output<E1>: Push<Output<E2>: Push>>,

Source

type Output = <<T as Push>::Output<E1> as Extend<(E2, E3)>>::Output

Source

impl<T, E1, E2> Extend<(E1, E2)> for T
where T: Push<Output<E1>: Push>,

Source

type Output = <<T as Push>::Output<E1> as Extend<(E2,)>>::Output

Source

impl<T, E1> Extend<(E1,)> for T
where T: Push,

Source

type Output = <<T as Push>::Output<E1> as Extend<()>>::Output

Source

impl<T> Extend<()> for T