pub trait Push {
type Output<E>;
}Expand description
Trait for adding a new member to a type set.
See Insert for a convenient type alias to add a member to a set.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".