pub trait SubsetOf<S: ?Sized> { }Expand description
Indicates that a type is a subset of set S.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait SubsetOf<S: ?Sized> { }Indicates that a type is a subset of set S.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".