Macros
- Set
- A macro for creating a [
Set] of types.
Structs
- Set
- A set of types.
Traits
- Contains
- Indicates that a type contains member
Ein its set. - SetEqual
- Indicates that two sets are equal, i.e., they contain the same members.
- Subset
Of - Indicates that a type is a subset of set
S. - Superset
Of - Indicates that a type is a superset of set
S. - TypeSet
- The main trait for representing a set of types.