Crate type_sets

Crate type_sets 

Macros

Set
A macro for creating a [Set] of types.

Structs

Set
A set of types.

Traits

Contains
Indicates that a type contains member E in its set.
SetEqual
Indicates that two sets are equal, i.e., they contain the same members.
SubsetOf
Indicates that a type is a subset of set S.
SupersetOf
Indicates that a type is a superset of set S.
TypeSet
The main trait for representing a set of types.