pub trait Extend<T: ?Sized> {
type Output: ?Sized;
}Expand description
Trait for extending a type set with another type set.
See Union for a convenient type alias to compute the union of two type sets.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".